==> segatex-8.500.tar.gz: segatex-8.500/src/segatex_yum.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXYUM_H
#define SEGATEXYUM_H

#include <qregexp.h>
#include <qdialog.h>
#include <q3textedit.h>
#include <qlabel.h>


class QLayout;
class QCheckBox;
class Q3TextEdit;
class QLineEdit;
class QPushButton;
class Q3Process;
class SegatexYumProcess;

class SegatexYum: public QDialog
{
	Q_OBJECT
public:
	SegatexYum(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
protected:

private slots:
	void yum_clicked();
	unsigned long getuid_uid_value();//unused
private:
	QLabel *packagesLabel;
	QCheckBox *targetedCheckBox;
	QCheckBox *minimalCheckBox;
	QCheckBox *permissiveCheckBox;
	QCheckBox *mlsCheckBox;
	QLineEdit *passwordLineEdit;
	Q3TextEdit *textEdit1;
	QPushButton *yumButton;
	QPushButton *closeButton;
	SegatexYumProcess *selinux_yum_process;
};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/segatex_yum.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXYUM_H
#define SEGATEXYUM_H

#include <QRegExp>
#include <QDialog>
#include <QTextEdit>
#include <QLabel>


class QLayout;
class QCheckBox;
class QTextEdit;
class QLineEdit;
class QPushButton;
class SegatexYumProcess;

class SegatexYum: public QDialog
{
	Q_OBJECT
public:
	SegatexYum(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
protected:

private slots:
	void yum_clicked();
	unsigned long getuid_uid_value();//unused
private:
	QLabel *packagesLabel;
	QCheckBox *targetedCheckBox;
	QCheckBox *minimalCheckBox;
	QCheckBox *permissiveCheckBox;
	QCheckBox *mlsCheckBox;
	QLineEdit *passwordLineEdit;
	QTextEdit *textEdit1;
	QPushButton *yumButton;
	QPushButton *closeButton;
	SegatexYumProcess *selinux_yum_process;
};

#endif
